==> MMDX-v1.10a-src.zip: MMDX-v1.10a-src/MikuMikuDanceXNADemo5/Game1.cs <==
using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;
using MikuMikuDance.XNA;
using MikuMikuDance.XNA.Model;
using MikuMikuDance.XNA.Motion;
using System.Diagnostics;
using MikuMikuDance.XNA.Accessory;

namespace MikuMikuDanceXNADemo5
{
    /// <summary>
    /// MikuMikuDance for XNÃf
    /// ̃fł͕[Vfł
    /// DirectX̃XLjObVTvۂ̂܂
    /// [V[vĐ̓tO̗p@̈Ă܂
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        //MikuMikuDance for XNA
        MikuMikuDanceXNA mmd;
        //MMDff[^
        MMDModel model;
        //MMD[Vf[^
        MMDBakedMotion motion;
        //MMDANZTf[^
        MMDAccessory negi;
        //XgbvEHb`
        Stopwatch stopwatch = new Stopwatch();
        public Game1()
        {
            //foCXMMDX̕Kv𖞂Ă邩`FbN
            graphics = new GraphicsDeviceManager(this);
            MikuMikuDanceXNA.CheckDevice(graphics);
            Content.RootDirectory = "Content";
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        /// <summary>
        /// LoadContent֐
        /// e탍[h͂Ń[hsĂƗǂ
        /// </summary>
        protected override void LoadContent()
        {
            //MikuMikuDanceXNA쐬
            mmd = new MikuMikuDanceXNA(this);
            //vWFNgContentɒǉĂMiku.pmdf[h
            //[hMikuMikuDanceXNA.LoadModel֐ōs
            //(ff[^͂ɂ܂肨؂肵܂B̃ft@CMITCZXKOł)
            model = mmd.LoadModel("Miku", this, Matrix.Identity);
            //ContentɒǉĂnegi.xANZT[h
            //(ANZTf[^͂ɂ܂肨؂肵܂B̃ft@CMITCZXKOł)
            negi = mmd.LoadAccessory("negi", this, Matrix.Identity);//vZbT̐ݒ14{g債Ă
            //ANZTpnegi-vac.vac[h
            MMD_VAC vac = mmd.LoadVAC("negi-vac");
            //fVACw肷邱ƂŎ(Matrixłw)
            model.SetAccessory(negi, vac);

            //ContentɒǉĂTrueMyHeart.vmd[V[h
            //[hMikuMikuDanceXNA.LoadMotion֐ōs
            motion = mmd.LoadBakedMotion("WalkB");//܂肤܂Ȃcc[V̖
            //f̃vC[Ăяo
            //[V0ԃgbNɃZbg
            model.Player.SetMotion(0, motion, true);
            model.Player.FramePerSecond = 60;//{Đ(ʏFPS30)

            mmd.Camera.CameraPos = new Vector3(-20, 20, 23);
            mmd.Camera.CameraTarget = new Vector3(0, 10, 3);
        }

        /// <summary>
        /// UnloadContent֐
        /// A[hKvȕ͂ŃA[hs
        /// </summary>
        protected override void UnloadContent()
        {
        }

        /// <summary>
        /// Abvf[g֐
        /// t[`ȊÕR[hɋLq
        /// </summary>
        /// <param name="gameTime">݂̎Ԃ̃XibvVbg\IuWFNg</param>
        protected override void Update(GameTime gameTime)
        {
            //XBoxRg[[Back{^I
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();
            //L[{[hEscL[I
            if (Keyboard.GetState().IsKeyDown(Keys.Escape))
                this.Exit();

            //ݍĐłȂ
            if (!model.Player.IsPlay(0))
            {
                //0ԃgbNɃZbgĂ郂[VZbg
                model.Player.Reset(0);
                //0ԃgbNɃZbgĂ郂[VĐ
                //[vƂɂɃZ^[{[Z̃YŃf̃[hWnCB
                //ɂA܂[vcc͂B([V삪܂肤܂ȂłB͂B)
                //([vĐ̗pȂAZ^[{[̈ʒu͕ςɁAvOŃ[Vɍ킹ă[hWnC郋[`Ȃcc)
                model.Player.Start(0, true, RepeatBehaviorFlag.ModifyByZ);
                //XgbvEHb`Jn
                stopwatch.Start();
            }
            mmd.Camera.CameraPos = new Vector3(-20, 20, 23f + (float)stopwatch.ElapsedMilliseconds / 102.5f);
            mmd.Camera.CameraTarget = new Vector3(0, 10, 3f + (float)stopwatch.ElapsedMilliseconds / 102.5f);

            //f̍ĐDrawableGameComponentpĂ邽
            //XNAɂ莩ŏs

            //XNAUpdates
            base.Update(gameTime);
        }

        /// <summary>
        /// Draw֐
        /// t[`R[hɋLq
        /// </summary>
        /// <param name="gameTime">݂̎Ԃ̃XibvVbg\IuWFNg</param>
        protected override void Draw(GameTime gameTime)
        {
            //ʂCornflowerBlueFŏ
            GraphicsDevice.Clear(Color.CornflowerBlue);

            //fDrawableGameComponentpĂ邽
            //XNAɂ莩ŕ`悳

            //XNADraws
            base.Draw(gameTime);
        }
    }
}

==> MMDX-v1.20a-src.zip: MMDX-v1.20a-src/MikuMikuDanceXNADemo5/Game1.cs <==
using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;
using MikuMikuDance.XNA;
using MikuMikuDance.XNA.Model;
using MikuMikuDance.XNA.Motion;
using System.Diagnostics;
using MikuMikuDance.XNA.Accessory;

namespace MikuMikuDanceXNADemo5
{
    /// <summary>
    /// MikuMikuDance for XNÃf
    /// ̃fł͕[Vfł
    /// DirectX̃XLjObVTvۂ̂܂
    /// [V[vĐ̓tO̗p@̈Ă܂
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        //MikuMikuDance for XNA
        MikuMikuDanceXNA mmd;
        //MMDff[^
        MMDModel model;
        //MMD[Vf[^
        MMDBakedMotion motion;
        //MMDANZTf[^
        MMDAccessory negi;
        //XgbvEHb`
        Stopwatch stopwatch = new Stopwatch();
        public Game1()
        {
            //foCXMMDX̕Kv𖞂Ă邩`FbN
            graphics = new GraphicsDeviceManager(this);
            MikuMikuDanceXNA.CheckDevice(graphics, true);
            Content.RootDirectory = "Content";
        }

        protected override void Initialize()
        {
            base.Initialize();
        }

        /// <summary>
        /// LoadContent֐
        /// e탍[h͂Ń[hsĂƗǂ
        /// </summary>
        protected override void LoadContent()
        {
            //MikuMikuDanceXNA쐬
            mmd = new MikuMikuDanceXNA(this);
            //vWFNgContentɒǉĂMiku.pmdf[h
            //[hMikuMikuDanceXNA.LoadModel֐ōs
            //(ff[^͂ɂ܂肨؂肵܂B̃ft@CMITCZXKOł)
            model = mmd.LoadModel("Miku", this, Matrix.Identity);
            //ContentɒǉĂnegi.xANZT[h
            //(ANZTf[^͂ɂ܂肨؂肵܂B̃ft@CMITCZXKOł)
            negi = mmd.LoadAccessory("negi", this, Matrix.Identity);//vZbT̐ݒ14{g債Ă
            //ANZTpnegi-vac.vac[h
            MMD_VAC vac = mmd.LoadVAC("negi-vac");
            //fVACw肷邱ƂŎ(Matrixłw)
            model.SetAccessory(negi, vac);

            //ContentɒǉĂTrueMyHeart.vmd[V[h
            //[hMikuMikuDanceXNA.LoadMotion֐ōs
            motion = mmd.LoadBakedMotion("WalkB");//܂肤܂Ȃcc[V̖
            //f̃vC[Ăяo
            //[V0ԃgbNɃZbg
            model.Player.SetMotion(0, motion, true);
            model.Player.FramePerSecond = 60;//{Đ(ʏFPS30)

            mmd.Camera.CameraPos = new Vector3(-20, 20, 23);
            mmd.Camera.CameraTarget = new Vector3(0, 10, 3);
        }

        /// <summary>
        /// UnloadContent֐
        /// A[hKvȕ͂ŃA[hs
        /// </summary>
        protected override void UnloadContent()
        {
        }

        /// <summary>
        /// Abvf[g֐
        /// t[`ȊÕR[hɋLq
        /// </summary>
        /// <param name="gameTime">݂̎Ԃ̃XibvVbg\IuWFNg</param>
        protected override void Update(GameTime gameTime)
        {
            //XBoxRg[[Back{^I
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();
            //L[{[hEscL[I
            if (Keyboard.GetState().IsKeyDown(Keys.Escape))
                this.Exit();

            //ݍĐłȂ
            if (!model.Player.IsPlay(0))
            {
                //0ԃgbNɃZbgĂ郂[VZbg
                model.Player.Reset(0);
                //0ԃgbNɃZbgĂ郂[VĐ
                //[vƂɂɃZ^[{[Z̃YŃf̃[hWnCB
                //ɂA܂[vcc͂B([V삪܂肤܂ȂłB͂B)
                //([vĐ̗pȂAZ^[{[̈ʒu͕ςɁAvOŃ[Vɍ킹ă[hWnC郋[`Ȃcc)
                model.Player.Start(0, true, RepeatBehaviorFlag.ModifyByZ);
                //XgbvEHb`Jn
                stopwatch.Start();
            }
            mmd.Camera.CameraPos = new Vector3(-20, 20, 23f + (float)stopwatch.ElapsedMilliseconds / 102.5f);
            mmd.Camera.CameraTarget = new Vector3(0, 10, 3f + (float)stopwatch.ElapsedMilliseconds / 102.5f);

            //f̍ĐDrawableGameComponentpĂ邽
            //XNAɂ莩ŏs

            //XNAUpdates
            base.Update(gameTime);
        }

        /// <summary>
        /// Draw֐
        /// t[`R[hɋLq
        /// </summary>
        /// <param name="gameTime">݂̎Ԃ̃XibvVbg\IuWFNg</param>
        protected override void Draw(GameTime gameTime)
        {
            //ʂCornflowerBlueFŏ
            GraphicsDevice.Clear(Color.CornflowerBlue);

            //fDrawableGameComponentpĂ邽
            //XNAɂ莩ŕ`悳

            //XNADraws
            base.Draw(gameTime);
        }
    }
}
